@@ -9,3 +9,9 @@ def test__base64_content_is_decoded(attachment_mail: PyMail):
     attachment = list(filter(lambda a: a.mimetype == 'image/png', attachment_mail.attachments)).pop()
 
     assert attachment.content == b'PNG here'
+
+
+def test__attachment_has_a_name(large_mail: PyMail):
+    payment_invoice_exists = len([a for a in large_mail.attachments if a.filename == 'Payment Invoice.zip'])
+
+    assert payment_invoice_exists == 1
